<?php

// Add Admin Menu
add_action('admin_menu', 'mumaraone_add_admin_menu');
function mumaraone_add_admin_menu() {
    add_menu_page(
        'Mumara One Settings',
        'Mumara One',
        'manage_options',
        'mumaraone-settings',
        'mumaraone_settings_page_html',
        'dashicons-email-alt2'
    );
}

// Settings Page HTML
function mumaraone_settings_page_html() {
    if (!current_user_can('manage_options')) {
        return;
    }

    // Save settings
    if (isset($_POST['mumaraone_save_settings'])) {
        update_option('mumaraone_api_token', sanitize_text_field($_POST['api_token']));
        update_option('mumaraone_from_name', sanitize_text_field($_POST['from_name']));
        update_option('mumaraone_from_email', sanitize_email($_POST['from_email']));
        update_option('mumaraone_reply_email', sanitize_email($_POST['reply_email']));
        update_option('mumaraone_use_wp_from_info', isset($_POST['use_wp_from_info']) ? 1 : 0);
        echo '<div class="updated"><p>Settings saved.</p></div>';
    }
    ?>

    <style>
        .wrap {
            margin-top: 10px;
            max-width: 450px;
            background: #F0F0F1;
            padding: 20px;
            border-radius: 8px;

        }

        h1 {
            font-size: 20px;
            color: #222;
            margin-bottom: 15px;
        }

        .form-table th {
            text-align: left;
            font-weight: 600;
        }

        .form-table td {
            padding-bottom: 0;
        }

        .form-table input {
            width: 100%;

            font-size: 14px;
            border: 1px solid #ccc;
            border-radius: 4px;
            box-sizing: border-box;
            margin-bottom: 0px; /* small margin below input */
        }
        .form-table th{

            padding: 0;
            vertical-align: top;
            vertical-align: top;
            text-align: left;
            padding: 20px 10px 20px 0;
            width: 121px;
            line-height: 1.3;
            font-weight: 600;
        }

        .form-table td{

            padding: 0;
            vertical-align: top;
            margin-bottom: 9px;
            padding: 15px 10px;
            line-height: 1.3;
            vertical-align: middle;
        }


        .form-table input:focus {
            border-color: #135e96;
        }

        .description {
            font-size: 12px;
            color: #135e96;
            margin-top: -2px;
        }

        /* Toggle Switch */
        .center-toggle {
            display: flex;
            align-items: center;
            margin-top: 15px;
            margin-bottom: 10px;
        }

        .override-text {
            font-size: 14px;
            font-weight: 500;
            color: #23282d;
            margin-right: 10px;
        }

        .switch {
            position: relative;
            display: inline-block;
            width: 28px;
            height: 14px;
        }

        .switch input {
            opacity: 0;
            width: 0;
            height: 0;
        }

        .slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #ccc;
            transition: 0.4s;
            border-radius: 14px;
        }

        .slider:before {
            position: absolute;
            content: "";
            height: 10px;
            width: 10px;
            border-radius: 50%;
            left: 2px;
            bottom: 2px;
            background-color: white;
            transition: 0.4s;
        }

        input:checked + .slider {
            background-color: #135e96;
        }

        input:checked + .slider:before {
            transform: translateX(14px);
        }

        /* Show/Hide From Info */
        .show-form {
            overflow: hidden;
            max-height: 0;
            transition: max-height 0.4s ease-in-out;
        }

        .show-form.active {
            max-height: 500px;
        }

        .button-group {
            margin-top: 15px;
            display: flex;
            gap: 10px;
        }
    </style>

    <div class="wrap">
        <h1>Mumara ONE Bridge API</h1>

        <form method="post">
            <table class="form-table">
                <tr>
                    <th><label for="api_token">Bridge API Key</label></th>
                    <td>
                        <input required type="text" name="api_token" id="api_token" value="<?php echo esc_attr(get_option('mumaraone_api_token')); ?>">
                    </td>
                </tr>
            </table>

            <div class="center-toggle">
                <span class="override-text">Override Sender Info</span>
                <label class="switch">

                    <input type="checkbox" name="use_wp_from_info" id="use_wp_from_info" value="1" <?php checked( get_option('mumaraone_use_wp_from_info'), 1 ); ?> >


                    <span class="slider"></span>
                </label>
            </div>

            <p id="toggleText" class="description" style="display: none;">
                If enabled, the sender information below will be used for all types of emails.
            </p>

            <div id="fromInfoForm" class="show-form">
                <table class="form-table">
                    <tr>
                        <th><label for="from_name">From Name</label></th>
                        <td>
                            <input type="text" name="from_name" id="from_name" value="<?php echo esc_attr(get_option('mumaraone_from_name')); ?>">
                            <p class="description">This will appear as the sender name.</p>
                        </td>
                    </tr>
                    <tr>
                        <th><label for="from_email">From Email</label></th>
                        <td>
                            <input type="email" name="from_email" id="from_email" required value="<?php echo esc_attr(get_option('mumaraone_from_email')); ?>">
                            <p class="description">(Email domain must be authenticated in your MumaraOne account.)</p>
                        </td>

                    </tr>

                </table>
            </div>

            <div style="margin-top: 15px; display: flex; gap: 5px; align-items: center;">
                <?php submit_button('Save Settings', 'primary', 'mumaraone_save_settings', false); ?>
                <a href="https://one.kb.mumara.com/en/articles/2-wordpress-plugin"
                   target="_blank"
                   class="button secondary"
                   style="font-size: 13px;">
                    Help Article
                </a>
            </div>

        </form>
    </div>

    <script>
        const form = document.getElementById('fromInfoForm');
        const toggleText = document.getElementById('toggleText');
        const useWpFromInfo = document.getElementById('use_wp_from_info');
        if(useWpFromInfo.checked) {
            form.classList.add('active');
            toggleText.style.display = 'block';
        } else {
            form.classList.remove('active');
            toggleText.style.display = 'none';
        }

        // Add event listener to toggle switch
        useWpFromInfo.addEventListener('change', function () {
            if (this.checked) {
                form.classList.add('active');
                toggleText.style.display = 'block';
            } else {
                form.classList.remove('active');
                toggleText.style.display = 'none';
            }
        });
    </script>

    <?php
}
?>
