<?php

class MumaraOne
{
    const API_URL = 'https://smtp.mumara.com/sendEmail';

    public function sendMail(array $params)
    {
        $contentHtml = $this->text_to_html($params['message']);
        $attachments = !empty($params['attachments']) ? $params['attachments'] : [];
        $fromName = isset($params['from_name']) ? $params['from_name'] : '';
        $fromEmail = $params['from_email'];

        $data = [
            'from' => "$fromName <$fromEmail>",
            'to' => $params['to'],
            'subject' => $params['subject'],
            'text' => '',
            'html' => $this->add_body_tag_if_missing(htmlspecialchars_decode($contentHtml))
        ];
        $additional = [];
        if (!empty($additional))
            $data['headers'] = $additional;
        $size = count($attachments);
        if ($size > 0) {
            for ($x = 0; $x < $size; $x++) {
                try {
                    $handle = fopen($attachments[$x], 'r');
                    $size_ = filesize($attachments[$x]);
                    if ($size_ > 0) {
                        $file_content = fread($handle, $size_);
                    } else {
                        fclose($handle);

                        continue;
                    }
                    fclose($handle);
                } catch (\Exception $e) {
                    continue;
                }
                $info = pathinfo($attachments[$x]);
                $basename = $info['basename'];
                $file_encoded = base64_encode($file_content);
                $attachmentArr[] = ['content' => $file_encoded, 'filename' => $basename, 'encoding' => 'base64'];
            }
        }
        if (isset($attachmentArr))
            $data['attachments'] = $attachmentArr;
        try {
            $API_URL = self::API_URL;
            $authorization = "Authorization: Bearer " . $params['api_token'];
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $API_URL);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data, JSON_UNESCAPED_SLASHES));
            curl_setopt($ch, CURLOPT_HTTPHEADER,
                ['Content-Type: application/json', $authorization]);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            $output = curl_exec($ch);
            if (curl_error($ch)) {
                $error = curl_error($ch);
            }
            curl_close($ch);
            if (isset($error)) {
                mumaraone_log_email('Email could not be sent. Error: ' . $error);
                return ['status' => 0, 'text' => 'Curl Error: ' . $error];
            }
            $response = json_decode($output, true);
            $status = $response['resCode'] == 250 ? 1 : 0;
            if ($status == 0)
                mumaraone_log_email('Email could not be sent. Error: ' . $response['message']);
            if (!empty($response['message'])) {
                mumaraone_log_email($response['message']);
                return ['status' => $status, 'text' => $response['message']];
            }
        } catch (\Exception $exception) {
            mumaraone_log_email('Email could not be sent. Error: ' . $exception->getMessage());
            return ['status' => 0, 'text' => $exception->getMessage()];
        }
    }

    private function add_body_tag_if_missing($html)
    {
        if (stripos($html, '<body') === false)
            $html = '<body>' . $html . '</body>';
        return $html;
    }

    private function text_to_html($text)
    {
        $text = htmlspecialchars($text);
        $text = '<p>' . preg_replace('/\n{2,}/', '</p><p>', $text) . '</p>';
        $text = nl2br($text); // Keep single line breaks as <br>
        return $text;
    }

    private function isHTML($string)
    {
        return ($string != strip_tags($string));
    }
}